==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/record/bean/RecordquotasummaryEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计汇总变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_quotasummary")
public class RecordquotasummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="quotasummary_code")
    private java.lang.String quotasummaryCode; // 变更记录编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 
    @TableField(value="quotasummary_id")
    private java.lang.Long quotasummaryId; // 限额设计汇总id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="cost_total")
    private java.math.BigDecimal costTotal; // 造价合计
    @TableField(value="partial_item_total")
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    @TableField(value="other_items_total")
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="recordquotasummarydetaillService", pidName = "recordMid")
    private List<RecordquotasummarydetaillEntity> quotasummarydetaillEntities = new ArrayList<>(); // 限额设计汇总变更记录子表
    

    /**
     * 变更记录编码
     */
    public java.lang.String getQuotasummaryCode() {
        return quotasummaryCode;
    }

    /**
     * 变更记录编码
     */
    public void setQuotasummaryCode(java.lang.String quotasummaryCode) {
        this.quotasummaryCode = quotasummaryCode;
    }
    /**
     * 
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 限额设计汇总id
     */
    public java.lang.Long getQuotasummaryId() {
        return quotasummaryId;
    }

    /**
     * 限额设计汇总id
     */
    public void setQuotasummaryId(java.lang.Long quotasummaryId) {
        this.quotasummaryId = quotasummaryId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 限额设计汇总变更记录子表
     */
    public List<RecordquotasummarydetaillEntity> getQuotasummarydetaillEntities() {
        return quotasummarydetaillEntities;
    }

    /**
     * 限额设计汇总变更记录子表
     */
    public void setQuotasummarydetaillEntities(List<RecordquotasummarydetaillEntity> quotasummarydetaillEntities) {
        this.quotasummarydetaillEntities = quotasummarydetaillEntities;
    }


}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/record/bean/RecordquotasummaryEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计汇总变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_quotasummary")
public class RecordquotasummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="quotasummary_code")
    private java.lang.String quotasummaryCode; // 变更记录编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 
    @TableField(value="quotasummary_id")
    private java.lang.Long quotasummaryId; // 原始单据id（限额设计汇总）
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="cost_total")
    private java.math.BigDecimal costTotal; // 造价合计
    @TableField(value="partial_item_total")
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    @TableField(value="other_items_total")
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="recordquotasummarydetaillService", pidName = "recordMid")
    private List<RecordquotasummarydetaillEntity> quotasummarydetailEntities = new ArrayList<>(); // 限额设计汇总变更记录子表
    

    /**
     * 变更记录编码
     */
    public java.lang.String getQuotasummaryCode() {
        return quotasummaryCode;
    }

    /**
     * 变更记录编码
     */
    public void setQuotasummaryCode(java.lang.String quotasummaryCode) {
        this.quotasummaryCode = quotasummaryCode;
    }
    /**
     * 
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }

    public Long getQuotasummaryId() {
        return quotasummaryId;
    }

    public void setQuotasummaryId(Long quotasummaryId) {
        this.quotasummaryId = quotasummaryId;
    }

    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 限额设计汇总变更记录子表
     */
    public List<RecordquotasummarydetaillEntity> getQuotasummarydetailEntities() {
        return quotasummarydetailEntities;
    }

    /**
     * 限额设计汇总变更记录子表
     */
    public void setQuotasummarydetailEntities(List<RecordquotasummarydetaillEntity> quotasummarydetailEntities) {
        this.quotasummarydetailEntities = quotasummarydetailEntities;
    }


}
